from flask import Flask, request, session
from flask_socketio import SocketIO, emit, join_room
import requests

from gencode import make_code
from game import Game

app = Flask('venture')
socketio = SocketIO(app, cors_allowed_origins="*")

games = {}

## Display

@socketio.on('new-game')
def on_newgame():
    data = {}
    session.room = make_code()
    session.game = Game(session.room)
    games[session.room] = session.game
    join_room(session.room)
    emit('set-code', {'code': session.room})

## Contestant

@socketio.on('contestant-join')
def on_join_contestant(data):
    sid = request.sid
    signature = data['signature']
    session.room = data['room']
    join_room(session.room)
    session.game = games[session.room]
    session.game.add_contestant(sid, signature)
    emit('contestant-joined', {'sid': sid, 'signature': signature }, to=session.room)

## Host

@socketio.on('host-join')
def on_join_host(data):
    sid = request.sid
    session.room = data['room']
    join_room(session.room)
    session.game = games[session.room]
    session.game.add_host(sid)
    emit('host-joined', {'sid': sid}, to=session.room)

@socketio.on('host-start')
def on_host_start():
    session.game.get_questions()
    emit('categories', [c.name for c in session.game.categories[:6]], to=session.room)

def main():
    socketio.run(app, host='0.0.0.0', debug=True)

if __name__ == '__main__':
    main()
